pub trait ArrayEncode {
const ARRAY_CONSTRUCTOR: Constructor;
// Required methods
fn array_encoded_size(&self) -> usize;
fn array_encode(&self, buf: &mut BytePages);
}Expand description
Defines routines to encode the type as an element of an AMQP array. It’s different from Encode in that it omits the type constructor (format code or described type definition) when encoding.
Required Associated Constants
Required Methods
Sourcefn array_encoded_size(&self) -> usize
fn array_encoded_size(&self) -> usize
Returns the size of the type when encoded as an element of an AMQP array.
Sourcefn array_encode(&self, buf: &mut BytePages)
fn array_encode(&self, buf: &mut BytePages)
Encodes the type as an element of an AMQP array.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".